#ifndef _vtg_h_
#define _vtg_h_

#include <windows.h>


typedef enum {
  TVAL_HFreq        = 0    ,  /* Horizontal frequency */
  TVAL_HTot         = 1    ,  /* Horizontal period */
  TVAL_HAct         = 2    ,  /* Horizontal active video */
  TVAL_HRes         = 3    ,  /* Horizontal resolution */
  TVAL_HSync        = 4    ,  /* Horizontal sync time */
  TVAL_HBp          = 5    ,  /* Horizontal backporch */
  TVAL_VTot         = 6    ,  /* Vertical  */
  TVAL_VRes         = 7    ,  /* Vertical active video (lines in FRAME)*/
  TVAL_VSync        = 8    ,  /* Vertical sync time */
  TVAL_VBp          = 9    ,  /* Vertical backporch */
  TVAL_HCSyn_po     = 10   ,  /* Horizontal sync polarity / Composite sync */
  TVAL_VSyn_po      = 11   ,  /* Vertical sync polarity */
  TVAL_GSyn         = 12   ,  /* Sync in green (G/T = in Green / TTL) */
  TVAL_CSyn_po      = 13   ,  /* omposite sync polarity */
  TVAL_HFp          = 14   ,  /* Horizontal frontporch */
  TVAL_VFp          = 15   ,  /* Vertical frontporch */
  TVAL_FPix         = 16   ,  /* Pixel frequency */
  TVAL_Interlace    = 17   ,  /* Interlaced / Non-interlaced */

  TVAL_HTot_pix     ,  /* Horizontal period in pixel units */
  TVAL_HSync_pix    ,  /* Horizontal sync time */
  TVAL_HBp_pix      ,  /* Horizontal backporch */
  TVAL_HFp_pix      ,  /* Horizontal frontporch */
  TVAL_VTot_tim     ,  /* Vertical  */
  TVAL_VSync_tim    ,  /* Vertical sync time */
  TVAL_VBp_tim      ,  /* Vertical backporch */
  TVAL_VFp_tim      ,  /* Vertical frontporch */
  TVAL_VFreq        ,  /* Vertical frequence */
  TVAL_VAct_lin     ,  /* Vertical active video lines in FIELD */

  TVAL_Brd_Left     ,  /* Left border in pixels */
  TVAL_Brd_Right    ,  /* Right border in pixels */
  TVAL_Brd_Top      ,  /* Top border in lines */
  TVAL_Brd_Bottom   ,  /* Bottom border in lines */

  TVAL_CSyn_mode    ,  /* Mode of comp. sync. (H+V, H xor V, ...) */
  TVAL_Video_BL_A   ,  /* Video blanked/active (= picture on/off) */

  TVAL_Count          /* Number of timing parameters in the array */
} timingindex_e;


#ifdef __cplusplus
extern "C" {
#endif

void	FAR _export PASCAL LockVTGDLL();
void	FAR _export PASCAL FreeVTGDLL();

int	FAR _export PASCAL GetVTGError(int cardnumber);
void	FAR _export PASCAL GetVTGErrorMessage(int errorCode, char *buffer);
void	FAR _export PASCAL GetVTGDLLVersion(char FAR* buffer);
int	FAR _export PASCAL IsVTGCardPresent(int cardnumber);
int	FAR _export PASCAL GetVtgCardVersion(int cardnumber, char FAR* buffer);
void	FAR _export PASCAL SetVTGINIFilePath(char *buffer);
void	FAR _export PASCAL GetVTGINIFilePath(char *buffer);
int	FAR _export PASCAL GetValueOfVTG_OK(void);
int     FAR _export PASCAL GetUnlockCol0(int cardnumber);

int	FAR _export PASCAL VTGFile_col(int cardnumber, char FAR* name);
int     FAR _export PASCAL VTGColor_SetRGB(int cardnumber,
				int index, unsigned char red,
				unsigned char green, unsigned char blue);
int     FAR _export PASCAL VTGColor_SetPalet(int cardnumber,
				unsigned char FAR* palet, int colorcount);
int     FAR _export PASCAL VTGColor_SetVideoLevel(int cardnumber, int level);
int     FAR _export PASCAL VTGColor_SetSyncLevel(int cardnumber, int level);

char FAR*   FAR _export PASCAL timLoadCheck_getRep(int cardnumber);
int	FAR _export PASCAL VTGFile_tim(int cardnumber, char FAR* name);
int     FAR _export PASCAL VTGTiming_SetFile(int cardnumber,
				char FAR* FileImage, char FAR* Name);
int	FAR _export PASCAL VTGFile_pic(int cardnumber, char FAR* name);
int     FAR _export PASCAL VTGTiming_GetValue(int cardnumber,
				int TimingIndex, char FAR* Value);
int FAR _export PASCAL VTG_getCurrTimDesc (int cardnumber, char *buf );
int FAR _export PASCAL VTG_setCurrTimDesc (int cardnumber, char *buf );
int FAR _export PASCAL VTG_getCurrPicDesc (int cardnumber, char *buf );
int FAR _export PASCAL VTG_setCurrPicDesc (int cardnumber, char *buf );
int FAR _export PASCAL VTG_getCurrColDesc (int cardnumber, char *buf );
int FAR _export PASCAL VTG_setCurrColDesc (int cardnumber, char *buf );
int     FAR _export PASCAL VTGTiming_SetValue(int cardnumber,
				int TimingIndex, char FAR* Value);
int FAR _export PASCAL VTGTiming_WaitVerBp(int cardnumber, short pos);
int FAR _export PASCAL VTGTiming_WaitVerBottomBorder(int cardnumber,short pos);
int FAR _export PASCAL VTGTiming_WaitVerTopBorder(int cardnumber, short pos);
int FAR _export PASCAL VTGTiming_WaitVerAct(int cardnumber, short pos);
int FAR _export PASCAL VTGTiming_WaitVerSync(int cardnumber, short pos);
int FAR _export PASCAL VTGTiming_WaitVerBlank(int cardnumber, short pos);
int FAR _export PASCAL VTGTiming_WaitVerPos(int cardnumber,unsigned short pos);

int     FAR _export PASCAL VTGTiming_SetPriority(int cardnumber, int Priority);
int 	FAR _export PASCAL VTGTiming_GetPriority(int cardnumber, int *Priority);

#ifdef VTG32_DLL
int 	FAR _export PASCAL VTGSave_tim(int cardnumber, char *name);
int     FAR _export PASCAL VTGTiming_GetLimits(int cardnumber,
				int TimingIndex, char FAR* minValue, char FAR* maxValue);
int     FAR _export PASCAL VTGTiming_GetLimitValues(int cardnumber,
				int TimingIndex, float FAR* minValue, float FAR* maxValue);
int 	FAR _export PASCAL VTGTiming_New(int cardnumber);
int 	FAR _export PASCAL VTG_IsNewCard(int cardnumber, int *retvalue);
#endif // VTG32_DLL
int     FAR _export PASCAL VTGTiming_SetSync(int cardnumber, unsigned long syncVal);
unsigned long FAR _export PASCAL VTGTiming_GetSync(int cardnumber);

int	FAR _export PASCAL VTG_setVTPFileName (int cardnumber,
				char FAR* name);
int	FAR _export PASCAL VTG_setPicSize (int cardnumber, long num);
long	FAR _export PASCAL VTG_getCurrPicSize (int cardnumber );
unsigned long	FAR _export PASCAL VTG_getMaxHeapSize (int cardnumber );

int	FAR _export PASCAL VTGPic_open (int cardnumber, int mode, int opts);
int	FAR _export PASCAL VTGPic_close (int cardnumber );
int	FAR _export PASCAL VTGPicstm_Absolute (int cardnumber);

int	FAR _export PASCAL VTGPicstm_Clear (int cardnumber );
int	FAR _export PASCAL VTGPicstm_Colour (int cardnumber, int colour );
int	FAR _export PASCAL VTGPicstm_Color (int cardnumber, int colour );

int	FAR _export PASCAL VTGPicstm_Line (int cardnumber,
				int x1, int y1, int x2, int y2);
int	FAR _export PASCAL VTGPicstm_Box (int cardnumber,
				int x1, int y1, int x2, int y2);
int	FAR _export PASCAL VTGPicstm_BlockSize (int cardnumber,
				int width, int height);

int	FAR _export PASCAL VTGPicstm_Copy (int cardnumber,
				int x1, int y1, int x2, int y2);
int	FAR _export PASCAL VTGPicstm_Transform (int cardnumber,
				int x1, int y1, int x2, int y2,
				int rot, int mirr,
				int hZoom, int vZoom);
int	FAR _export PASCAL VTGPicstm_Circle (int cardnumber,
				int x, int y, int rad);

int	FAR _export PASCAL VTGPicstm_Ellipse (int cardnumber,
				int par_x, int par_y, int hrad, int vrad);
int	FAR _export PASCAL VTGPicstm_Fill (int cardnumber, int x, int y);

int	FAR _export PASCAL VTG_IOFlush(int cardnumber);
int	FAR _export PASCAL VTGPicstm_Font(int cardnumber, char *fontname);
int	FAR _export PASCAL VTGPicstm_PermanentFont(int cardnumber,
							char *fontname);
int	FAR _export PASCAL VTGPicstm_TextPos(int cardnumber, int x, int y);
int	FAR _export PASCAL VTGPicstm_Tscale(int cardnumber, int x, int y);
int	FAR _export PASCAL VTGPicstm_TextC(int cardnumber, char *txt);
int	FAR _export PASCAL VTGPicstm_Text(int cardnumber, char *txt);
int	FAR _export PASCAL VTGPicstm_TextC16(int cardnumber, short *txt);
int	FAR _export PASCAL VTGPicstm_Text16(int cardnumber, short *txt);
int	FAR _export PASCAL VTGPicstm_ComplexTextC(int cardnumber, char *txt);
int	FAR _export PASCAL VTGPicstm_ComplexText(int cardnumber, char *txt);
int	FAR _export PASCAL VTGPicstm_ComplexTextC16(int cardnumber, char *txt);
int	FAR _export PASCAL VTGPicstm_ComplexText16(int cardnumber, char *txt);
int	FAR _export PASCAL VTGPicstm_TextBackgroundColor(int cardnumber,
								int colour );
int	FAR _export PASCAL VTGPicstm_TextBackgroundColour (int cardnumber,
								int colour );
int	FAR _export PASCAL VTGPicstm_Bitmap(int cardnumber, unsigned int id, int x,
									int y);
int	FAR _export PASCAL VTGPicstm_LoadPCXFile(int cardnumber, unsigned int id,
						char *PCXName, char *VTCName);
int	FAR _export PASCAL VTGPicstm_Hdump4(int cardnumber, unsigned int id,
								char *name);

#ifdef VTG32_DLL
int FAR _export PASCAL VTGLoad_col(int cardnumber, char *name);
int FAR _export PASCAL VTGSave_col(int cardnumber, char *name);
int FAR _export PASCAL VTGLoad_pic(int cardnumber, char *name);
int FAR _export PASCAL VTGSave_pic(int cardnumber, char *name);
#ifdef __cplusplus
 int FAR _export PASCAL VTGStream_pic(int cardnumber, istream &is);
#endif // __cplusplus
long FAR _export PASCAL VTG_getCurrPicSizeStr (int cardnumber );
int FAR _export PASCAL VTG_getCurrPicStr (int cardnumber, char *buf, int bufsize );
int FAR _export PASCAL VTG_getErrorLineNum (int cardnumber );
char FAR _export PASCAL VTG_OpenCard (int cardnumber );
int FAR _export PASCAL VTG_CloseCard (int cardnumber );
void FAR _export PASCAL VTGSetReturnValues(int okvalue, int errorvalue);
int	FAR _export PASCAL VtgCardScan(char FAR* buffer);

int FAR _export PASCAL VTGSave_bitmap(int cardnumber, char *name);
int FAR _export PASCAL VTGLoad_bitmap(int cardnumber, char *name);
int FAR _export PASCAL VTGExternal_bitmap(int cardnumber, char *name, int format, int x, int y, char *bits);
int FAR _export PASCAL VTGAttach_bitmap(int cardnumber, char *name, int format, int x, int y, char *bits);
int FAR _export PASCAL VTGDetach_bitmap(int cardnumber, char *name);
int FAR _export PASCAL VTGGet_bitmap(int cardnumber, char *name, int *pformat, int *pwidth, int *pheight, char **pbits);
int FAR _export PASCAL VTGQuery_bitmaps(int cardnumber, char *list);
int FAR _export PASCAL VTG_setBitmapPath(int cardnumber, char *pathname);

int FAR _export PASCAL VTGDDCReport(int cardnumber, 
	unsigned char stop, unsigned long *pcapability);
int FAR _export PASCAL VTGGetDDCCaps(int cardnumber, 
	int *capable, int *minfreq, int *maxfreq);
int FAR _export PASCAL VTGDDC1_Transfer(int cardnumber, 
	unsigned char *data, unsigned long *presult);
int FAR _export PASCAL VTGDDC2B_Transfer(int cardnumber, 
	unsigned char slave_addr, unsigned char *data, unsigned long num, unsigned char rw, unsigned long *presult);
int FAR _export PASCAL VTGDDC2AB_Transfer(int cardnumber, 
	unsigned char *data_send, unsigned long num_send, unsigned char *data_receive, char readflag, long *presult);
int FAR _export PASCAL VTGDDCClockSpeed(int cardnumber, unsigned char clock);
int FAR _export PASCAL VTGDDCSoftwareReset(int cardnumber);
int FAR _export PASCAL VTGDDC_SetPort(int cardnumber, unsigned char val);
int FAR _export PASCAL VTGDDC_GetPort(int cardnumber, unsigned char *pval);
int FAR _export PASCAL VTGDDCPower(int cardnumber, unsigned char onoff);
int FAR _export PASCAL VTGDDC1_Monitor(int cardnumber, unsigned char mode);
int FAR _export PASCAL VTGDDC1_Status(int cardnumber, unsigned char *presult);
int FAR _export PASCAL VTGDDC1_BitCounter(int cardnumber, unsigned short *presult);
int FAR _export PASCAL VTGBackupTiming_For_DDC(int cardnumber);
int FAR _export PASCAL VTGRestoreTiming_For_DDC(int cardnumber);

#endif // VTG32_DLL

int FAR _export PASCAL VTGColor_GetRGB (int cardnumber, int index, int *R,
                                                        int *G, int *B);
int FAR _export PASCAL VTGColor_SetRed (int cardnumber, int index, unsigned char value);
int FAR _export PASCAL VTGColor_SetGreen (int cardnumber, int index, unsigned char value);
int FAR _export PASCAL VTGColor_SetBlue (int cardnumber, int index, unsigned char value);
int FAR _export PASCAL VTGColor_GetUnlockCol0 (int cardnumber);
int FAR _export PASCAL VTGColor_GetVideoLevel (int cardnumber, int *level);
int FAR _export PASCAL VTGColor_GetSyncLevel (int cardnumber, int *level);

int FAR _export PASCAL GetVTGVersions (int cardnumber, char **buffer);
int FAR _export PASCAL VTG_setFontPath(int cardnumber, char *name);
#ifdef __cplusplus
};
#endif

#endif /* _vtg_h_ */

